@@ -1,20 +1,21 @@
 
 #define HOST_CPU "i386"
 #define HOST_VENDOR "unknown"
-#define HOST_OS "openbsd2.3"
+#define HOST_OS "openbsd2.4"
 #define HOST_OS_NAME "openbsd2"
-#define HOST_OS_VERSION "2.3"
+#define HOST_OS_VERSION "2.4"
 #define HOST_ARCH "i386"
 #define HOST_NAME "t-rex"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Sun Oct 18 19:11:54 PDT 1998"
+#define CONFIG_DATE "Mon Jul 19 10:32:57 EST 1999"
 #define PACKAGE "am-utils"
-#define VERSION "6.0b1"
+#define VERSION "6.0.1s9"
 #define PACKAGE "am-utils"
-#define VERSION "6.0b1"
+#define VERSION "6.0.1s9"
 #define DEBUG 1
 #define YYTEXT_POINTER 1
 #define HAVE_LIBRPCSVC 1
+#define HAVE_ALLOCA 1
 #define STDC_HEADERS 1
 #define HAVE_WAIT3 1
 #define HAVE__SETERR_REPLY 1
@@ -113,6 +114,7 @@
 #define HAVE_SYS_WAIT_H 1
 #define HAVE_ARPA_NAMESER_H 1
 #define HAVE_ARPA_INET_H 1
+#define HAVE_ISOFS_CD9660_CD9660_MOUNT_H 1
 #define HAVE_MACHINE_ENDIAN_H 1
 #define HAVE_NET_IF_H 1
 #define HAVE_NET_ROUTE_H 1
@@ -122,7 +124,6 @@
 #define HAVE_NFS_NFSMOUNT_H 1
 #define HAVE_NFS_NFSPROTO_H 1
 #define HAVE_NFS_RPCV2_H 1
-#define HAVE_NFS_RPCV2_H 1
 #define HAVE_RPC_PMAP_CLNT_H 1
 #define HAVE_RPC_PMAP_PROT_H 1
 #define HAVE_RPC_RPC_H 1
@@ -155,6 +156,7 @@
 #define HAVE_SYS_UIO_H 1
 #define HAVE_SYS_UTSNAME_H 1
 #define HAVE_SYS_VNODE_H 1
+#define HAVE_UFS_UFS_UFSMOUNT_H 1
 #define HAVE_ASSERT_H 1
 #define HAVE_CTYPE_H 1
 #define HAVE_ERRNO_H 1
@@ -203,6 +205,7 @@
 #define voidp void *
 #define HAVE_EXTERN_SYS_ERRLIST 1
 #define HAVE_EXTERN_OPTARG 1
+#define HAVE_EXTERN_CLNT_SPCREATEERROR 1
 #define HAVE_EXTERN_CLNT_SPERRNO 1
 #define HAVE_EXTERN_FREE 1
 #define HAVE_EXTERN_GET_MYADDRESS 1
@@ -214,6 +217,7 @@
 #define HAVE_EXTERN_GETWD 1
 #define HAVE_EXTERN_MKSTEMP 1
 #define HAVE_EXTERN_SBRK 1
+#define HAVE_EXTERN_SETEUID 1
 #define HAVE_EXTERN_STRCASECMP 1
 #define HAVE_EXTERN_STRDUP 1
 #define HAVE_EXTERN_STRSTR 1
@@ -238,15 +242,10 @@
 #define HAVE_FIELD_NFS_ARGS_T_VERSION 1
 #define HAVE_FIELD_STRUCT_IFREQ_IFR_ADDR 1
 #define HAVE_FIELD_STRUCT_SOCKADDR_SA_LEN 1
-#define HAVE_FGETS 1
 #define HAVE_MAP_FILE 1
-#define HAVE_DBM_OPEN 1
 #define HAVE_MAP_NDBM 1
-#define HAVE_YP_GET_DEFAULT_DOMAIN 1
 #define HAVE_MAP_NIS 1
-#define HAVE_GETPWNAM 1
 #define HAVE_MAP_PASSWD 1
-#define HAVE_OPENDIR 1
 #define HAVE_MAP_UNION 1
 #define HAVE_FS_CDFS 1
 #define HAVE_FS_LOFS 1
@@ -273,6 +272,7 @@
 #define MOUNT_TYPE_NFS MOUNT_NFS
 #define MOUNT_TYPE_NFS3 MOUNT_NFS3
 #define MOUNT_TYPE_UFS MOUNT_UFS
+#define MOUNT_TYPE_XFS MOUNT_XFS
 #define MOUNT_TYPE_CDFS MOUNT_CD9660
 #define MOUNT_TYPE_PCFS MOUNT_MSDOS
 #define MOUNT_TYPE_MFS MOUNT_MFS
@@ -318,6 +318,8 @@
 #define MNT2_NFS_OPT_SOFT 0x1
 #define MNT2_NFS_OPT_TIMEO 0x8
 #define MNT2_NFS_OPT_WSIZE 0x2
+#define MNT2_CDFS_OPT_EXTATT 0x4
+#define MNT2_CDFS_OPT_GENS 0x2
+#define MNT2_CDFS_OPT_NORRIP 0x1
 #define HIDE_MOUNT_TYPE "nfs"
-#define HAVE_GETMNTINFO 1
 #define USE_CONNECTED_NFS_SOCKETS 1
